OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Couldn't send mail to following users: %s ",
    "Turned on maintenance mode" : "Turned on maintenance mode",
    "Turned off maintenance mode" : "Turned off maintenance mode",
    "Updated database" : "Updated database",
    "Checked database schema update" : "Checked database schema update",
    "Checked database schema update for apps" : "Checked database schema update for apps",
    "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
    "Repair warning: " : "Repair warning: ",
    "Repair error: " : "Repair error: ",
    "Following incompatible apps have been disabled: %s" : "Following incompatible apps have been disabled: %s",
    "Following 3rd party apps have been disabled: %s" : "Following 3rd party apps have been disabled: %s",
    "Invalid file provided" : "Invalid file provided",
    "No image or file provided" : "No image or file provided",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
    "No crop data provided" : "No crop data provided",
    "No valid crop data provided" : "No valid crop data provided",
    "Crop is not square" : "Crop is not square",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "January" : "January",
    "February" : "February",
    "March" : "March",
    "April" : "April",
    "May" : "May",
    "June" : "June",
    "July" : "July",
    "August" : "August",
    "September" : "September",
    "October" : "October",
    "November" : "November",
    "December" : "December",
    "Settings" : "Settings",
    "Saving..." : "Saving...",
    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
    "I know what I'm doing" : "I know what I'm doing",
    "Password can not be changed. Please contact your administrator." : "Password can not be changed. Please contact your administrator.",
    "No" : "No",
    "Yes" : "Yes",
    "Choose" : "Choose",
    "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Error loading message template: {error}",
    "read-only" : "read-only",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file conflict","{count} file conflicts"],
    "One file conflict" : "One file conflict",
    "New Files" : "New Files",
    "Already existing files" : "Already existing files",
    "Which files do you want to keep?" : "Which files do you wish to keep?",
    "If you select both versions, the copied file will have a number added to its name." : "If you select both versions, the copied file will have a number added to its name.",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "(all selected)" : "(all selected)",
    "({count} selected)" : "({count} selected)",
    "Error loading file exists template" : "Error loading file exists template",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Your web server is not yet set up properly to allow file synchronisation because the WebDAV interface seems to be broken.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest enabling the Internet connection for this server.",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting.",
    "Shared" : "Shared",
    "Shared with {recipients}" : "Shared with {recipients}",
    "Share" : "Share",
    "Error" : "Error",
    "Error while sharing" : "Error whilst sharing",
    "Error while unsharing" : "Error whilst unsharing",
    "Error while changing permissions" : "Error whilst changing permissions",
    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
    "Shared with you by {owner}" : "Shared with you by {owner}",
    "Share with users or groups …" : "Share with users or groups …",
    "Share with users, groups or remote users …" : "Share with users, groups or remote users …",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Share with people on other ownClouds using the syntax username@example.com/owncloud",
    "Share link" : "Share link",
    "The public link will expire no later than {days} days after it is created" : "The public link will expire no later than {days} days after it is created",
    "Link" : "Link",
    "Password protect" : "Password protect",
    "Password" : "Password",
    "Choose a password for the public link" : "Choose a password for the public link",
    "Allow editing" : "Allow editing",
    "Email link to person" : "Email link to person",
    "Send" : "Send",
    "Set expiration date" : "Set expiration date",
    "Expiration" : "Expiration",
    "Expiration date" : "Expiration date",
    "An error occured. Please try again" : "An error occured. Please try again",
    "Adding user..." : "Adding user...",
    "group" : "group",
    "remote" : "remote",
    "Resharing is not allowed" : "Resharing is not allowed",
    "Shared in {item} with {user}" : "Shared in {item} with {user}",
    "Unshare" : "Unshare",
    "notify by email" : "notify by email",
    "can share" : "can share",
    "can edit" : "can edit",
    "access control" : "access control",
    "create" : "create",
    "change" : "change",
    "delete" : "delete",
    "Password protected" : "Password protected",
    "Error unsetting expiration date" : "Error unsetting expiration date",
    "Error setting expiration date" : "Error setting expiration date",
    "Sending ..." : "Sending ...",
    "Email sent" : "Email sent",
    "Warning" : "Warning",
    "The object type is not specified." : "The object type is not specified.",
    "Enter new" : "Enter new",
    "Delete" : "Delete",
    "Add" : "Add",
    "Edit tags" : "Edit tags",
    "Error loading dialog template: {error}" : "Error loading dialog template: {error}",
    "No tags selected for deletion." : "No tags selected for deletion.",
    "unknown text" : "unknown text",
    "Hello world!" : "Hello world!",
    "sunny" : "sunny",
    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
    "Hello {name}" : "Hello {name}",
    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
    "{version} is available. Get more information on how to update." : "{version} is available. Get more information on how to update.",
    "Updating {productName} to version {version}, this may take a while." : "Updating {productName} to version {version}, this may take a while.",
    "Please reload the page." : "Please reload the page.",
    "The update was unsuccessful. " : "The update was unsuccessful. ",
    "The update was successful. Redirecting you to ownCloud now." : "The update was successful. Redirecting you to ownCloud now.",
    "Couldn't reset password because the token is invalid" : "Couldn't reset password because the token is invalid",
    "Couldn't send reset email. Please make sure your username is correct." : "Couldn't send reset email. Please make sure your username is correct.",
    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Couldn't send reset email because there is no email address for this username. Please contact your administrator.",
    "%s password reset" : "%s password reset",
    "Use the following link to reset your password: {link}" : "Use the following link to reset your password: {link}",
    "New password" : "New password",
    "New Password" : "New Password",
    "Reset password" : "Reset password",
    "Searching other places" : "Searching other places",
    "No search results in other places" : "No search results in other places",
    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} search result in other places","{count} search results in other places"],
    "Personal" : "Personal",
    "Users" : "Users",
    "Apps" : "Apps",
    "Admin" : "Admin",
    "Help" : "Help",
    "Error loading tags" : "Error loading tags",
    "Tag already exists" : "Tag already exists",
    "Error deleting tag(s)" : "Error deleting tag(s)",
    "Error tagging" : "Error tagging",
    "Error untagging" : "Error untagging",
    "Error favoriting" : "Error favouriting",
    "Error unfavoriting" : "Error unfavouriting",
    "Access forbidden" : "Access denied",
    "File not found" : "File not found",
    "The specified document has not been found on the server." : "The specified document has not been found on the server.",
    "You can click here to return to %s." : "You can click here to return to %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n",
    "The share will expire on %s." : "The share will expire on %s.",
    "Cheers!" : "Cheers!",
    "Internal Server Error" : "Internal Server Error",
    "The server encountered an internal error and was unable to complete your request." : "The server encountered an internal error and was unable to complete your request.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report.",
    "More details can be found in the server log." : "More details can be found in the server log.",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Line: %s",
    "Trace" : "Trace",
    "Security warning" : "Security warning",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
    "Username" : "Username",
    "Storage & database" : "Storage & database",
    "Data folder" : "Data folder",
    "Configure the database" : "Configure the database",
    "Only %s is available." : "Only %s is available.",
    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
    "For more details check out the documentation." : "For more details check out the documentation.",
    "Database user" : "Database user",
    "Database password" : "Database password",
    "Database name" : "Database name",
    "Database tablespace" : "Database tablespace",
    "Database host" : "Database host",
    "Performance warning" : "Performance warning",
    "SQLite will be used as database." : "SQLite will be used as database.",
    "For larger installations we recommend to choose a different database backend." : "For larger installations we recommend to choose a different database backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
    "Finish setup" : "Finish setup",
    "Finishing …" : "Finishing …",
    "Need help?" : "Need help?",
    "See the documentation" : "See the documentation",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "Log out" : "Log out",
    "Search" : "Search",
    "Server side authentication failed!" : "Server side authentication failed!",
    "Please contact your administrator." : "Please contact your administrator.",
    "An internal error occured." : "An internal error occured.",
    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
    "Forgot your password? Reset it!" : "Forgot your password? Reset it!",
    "remember" : "remember",
    "Log in" : "Log in",
    "Alternative Logins" : "Alternative Logins",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>",
    "This ownCloud instance is currently in single user mode." : "This ownCloud instance is currently in single user mode.",
    "This means only administrators can use the instance." : "This means only administrators can use the instance.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
    "Thank you for your patience." : "Thank you for your patience.",
    "You are accessing the server from an untrusted domain." : "You are accessing the server from an untrusted domain.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain.",
    "Add \"%s\" as trusted domain" : "Add \"%s\" as a trusted domain",
    "%s will be updated to version %s." : "%s will be updated to version %s.",
    "The following apps will be disabled:" : "The following apps will be disabled:",
    "The theme %s has been disabled." : "The theme %s has been disabled.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "Start update" : "Start update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again."
},
"nplurals=2; plural=(n != 1);");
